==> org.opennms.features.flows.api-25.0.0-20191016.141845-119-sources.jar: org/opennms/netmgt/flows/api/FlowSource.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.flows.api;

import java.util.Objects;

public class FlowSource {
    private final String location;
    private final String sourceAddress;

    public FlowSource(String location, String sourceAddress) {
        this.location = Objects.requireNonNull(location);
        this.sourceAddress = Objects.requireNonNull(sourceAddress);
    }

    public String getLocation() {
        return location;
    }

    public String getSourceAddress() {
        return sourceAddress;
    }
}

==> org.opennms.features.flows.api-27.0.0-20200508.042814-22-sources.jar: org/opennms/netmgt/flows/api/FlowSource.java <==
/*******************************************************************************
 * This file is part of OpenNMS(R).
 *
 * Copyright (C) 2017 The OpenNMS Group, Inc.
 * OpenNMS(R) is Copyright (C) 1999-2017 The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
 *
 * OpenNMS(R) is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * OpenNMS(R) is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OpenNMS(R).  If not, see:
 *      http://www.gnu.org/licenses/
 *
 * For more information contact:
 *     OpenNMS(R) Licensing <license@opennms.org>
 *     http://www.opennms.org/
 *     http://www.opennms.com/
 *******************************************************************************/

package org.opennms.netmgt.flows.api;

import java.util.Objects;

import org.opennms.core.rpc.utils.mate.ContextKey;

public class FlowSource {
    private final String location;
    private final String sourceAddress;
    private ContextKey contextKey;

    public FlowSource(final String location, final String sourceAddress, final ContextKey contextKey) {
        this.location = Objects.requireNonNull(location);
        this.sourceAddress = Objects.requireNonNull(sourceAddress);
        this.contextKey = contextKey;

    }

    public String getLocation() {
        return location;
    }

    public String getSourceAddress() {
        return sourceAddress;
    }

    public ContextKey getContextKey() {
        return contextKey;
    }
}
